@@ -76,8 +76,10 @@ as.matrix.SpatialGridDataFrame = function(x, byrow = FALSE) {
 	matrix(x@data[[1]], x@grid@cells.dim[1], x@grid@cells.dim[2], byrow=byrow)
 }
 
-setAs("SpatialPixelsDataFrame", "matrix", function(from) as.matrix.SpatialPixelsDataFrame(from))
-setAs("SpatialGridDataFrame", "matrix", function(from) as.matrix.SpatialGridDataFrame(from))
+setAs("SpatialPixelsDataFrame", "matrix", function(from) 
+	as.matrix.SpatialPixelsDataFrame(from))
+setAs("SpatialGridDataFrame", "matrix", function(from) 
+	as.matrix.SpatialGridDataFrame(from))
 
 as.data.frame.SpatialPixelsDataFrame = function(x, row.names, optional)
 	as.data.frame(as(x, "SpatialPointsDataFrame"))
@@ -85,8 +87,10 @@ as.data.frame.SpatialPixelsDataFrame = function(x, row.names, optional)
 as.data.frame.SpatialGridDataFrame = function(x, row.names, optional)
 	as.data.frame(as(x, "SpatialPixelsDataFrame"))
 
-setAs("SpatialPixelsDataFrame", "data.frame", function(from) as.data.frame.SpatialPixelsDataFrame(from))
-setAs("SpatialGridDataFrame", "data.frame", function(from) as.data.frame.SpatialGridDataFrame(from))
+setAs("SpatialPixelsDataFrame", "data.frame", function(from) 
+	as.data.frame.SpatialPixelsDataFrame(from))
+setAs("SpatialGridDataFrame", "data.frame", function(from) 
+	as.data.frame.SpatialGridDataFrame(from))
 
 setAs("SpatialPixelsDataFrame", "AttributeList", function(from) from@data)
 setAs("SpatialGridDataFrame", "AttributeList", function(from) from@data)
